========
Commands
========

.. toctree::
   :maxdepth: 0

   commands/galaxy-wait
   commands/get-tool-list
   commands/run-data-managers
   commands/setup-data-libraries
   commands/shed-tools
   commands/install-tool-deps
   commands/workflow-install
   commands/workflow-to-tools
